==> dasu_4.11.jar: edu/northwestern/dasu/util/LoggerFilter.java <==
/**
 * Dasu Project
 *
 * File:         LoggerFilter.java
 * RCS:          $Id: LoggerFilter.java,v 1.0 Sep 25, 2012 1:30:58 PM mas939 Exp $
 * Description:  LoggerFilter class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Sep 25, 2012 at 1:30:58 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.util
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.util;

import java.util.HashSet;
import java.util.logging.Filter;
import java.util.logging.LogRecord;

import org.apache.log4j.Level;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The LoggerFilter class ...
 * 
 * Format of Log messages should be the following:
 * 
 * MODULE: message
 *
 * where MODULE describes the common functionality of the message, say REPORTING, TESTING, EXTERNAL_EXPERIMENT
 * 
 * 
 */

public class LoggerFilter implements Filter {

	private HashSet<String> moduleNames  = new HashSet();
	
	public LoggerFilter() {		
	}
	
	public LoggerFilter(String moduleName) {		
		this.moduleNames.add(moduleName);		
	}

	public LoggerFilter(String[] moduleNames) {
		
		for ( int i=0; i < moduleNames.length; i++) {
			this.moduleNames.add(moduleNames[i]);
		}
	}
	
	public boolean isLoggable(LogRecord lr) {
		
		String msg = lr.getMessage();
		
		if (( moduleNames.size() == 0 ) || ( lr.getLevel().intValue() > java.util.logging.Level.INFO.intValue())) {
			return true;
		}
		
		else {
			
			boolean module = false;
			
			
			
			for ( String moduleName : moduleNames )
				module = module || msg.contains(moduleName);
			
			return  ( !(moduleNames.size() > 0 ^ module) );
			
		}
		
	}

}

==> dasu_5.1.jar: edu/northwestern/dasu/util/LoggerFilter.java <==
/**
 * Dasu Project
 *
 * File:         LoggerFilter.java
 * RCS:          $Id: LoggerFilter.java,v 1.0 Sep 25, 2012 1:30:58 PM mas939 Exp $
 * Description:  LoggerFilter class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Sep 25, 2012 at 1:30:58 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.util
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.util;

import java.util.HashSet;
import java.util.logging.Filter;
import java.util.logging.LogRecord;

import org.apache.log4j.Level;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The LoggerFilter class ...
 * 
 * Format of Log messages should be the following:
 * 
 * MODULE: message
 *
 * where MODULE describes the common functionality of the message, say REPORTING, TESTING, EXTERNAL_EXPERIMENT
 * 
 * 
 */

public class LoggerFilter implements Filter {

	private HashSet<String> moduleNames  = new HashSet();
	
	public LoggerFilter() {		
	}
	
	public LoggerFilter(String moduleName) {		
		this.moduleNames.add(moduleName);		
	}

	public LoggerFilter(String[] moduleNames) {
		
		for ( int i=0; i < moduleNames.length; i++) {
			this.moduleNames.add(moduleNames[i]);
		}
	}
	
	public boolean isLoggable(LogRecord lr) {
		
		String msg = lr.getMessage();
		
		if (( moduleNames.size() == 0 ) || ( lr.getLevel().intValue() > java.util.logging.Level.INFO.intValue())) {
			return true;
		}
		
		else {
			
			boolean module = false;
			
			
			
			for ( String moduleName : moduleNames )
				module = module || msg.startsWith(moduleName);
			
			return  ( !(moduleNames.size() > 0 ^ module) );
			
		}
		
	}

}
